@@ -6,10 +6,9 @@ import json
 import re
 import sys
 from getopt import getopt
-try:
-    from JsonToMarkdown import libmd
-except ImportError:
-    import libmd
+BASE_DIR = os.path.dirname(os.path.abspath(__file__))
+sys.path.append(BASE_DIR)
+import libmd
 
 __version__ = 'v1.3.1'
 
@@ -25,7 +24,8 @@ class TranslateJson(object):
         else:
             self.link_path = os.path.join(link_path, '_json_output')
         self.dir_type = dir_type
-        self.output_dir = 'registers/'
+        #self.output_dir = 'registers/'
+        self.output_dir = link_path
         self.output_md = output_md
         self.output_gitbook = output_gitbook
         self.output_xmind = output_xmind
@@ -526,22 +526,23 @@ class TranslateJson(object):
 
             with open(reg_path, 'w') as fd:
                 for i in fields:
-                    fd.write('# ' + i['range'].replace('[','(').replace(']', ')') \
-                            + '_' + i['name'] + ' (' + str(addr) + '_' + name + ')\n')
-                    if 'description' in i:
-                        for d in i['description'].split(';'):
-                            fd.write('## ' + d + ' (' + str(addr) + '_' + name + '->' \
-                                    + i['range'].replace('[','(').replace(']', ')') \
-                                    + '_' + i['name'] + ')\n')
+                    #fd.write('### ' + i['range'].replace('[','').replace(']', '').replace(':', '_') \
+                    #        + '_' + i['name'] + '\n')
+                    fd.write('### ' + i['name'] + '\n')
+                    #if 'description' in i:
+                    #    for d in i['description'].split(';'):
+                    #        fd.write('#### ' + d + ' (' + str(addr) + '_' + name + '->' \
+                    #                + i['range'].replace('[','(').replace(']', ')') \
+                    #                + '_' + i['name'] + ')\n')
         with open(os.path.join(self.output_dir, 'list.md'), 'w') as fl:
             fl.write(list_data)
-        print("Json to obsidian Success : ./registers")
+        print("Json to obsidian Success : " +  self.output_dir)
 
 
 def usage():
     """
     Usage:
-        jsontomd -f json_file
+        jsontomd -f json_file -l target_dir
       exp
         jsontomd -f npu_register.json
 
@@ -554,9 +555,9 @@ def main():
     if len(sys.argv) <= 1:
             usage()
             sys.exit()
-    opts,args = getopt(sys.argv[1:],"f:hv")
+    opts,args = getopt(sys.argv[1:],"f:l:hvc")
     js_file = "demo.json"
-    link_path = ''
+    link_path = 'registers'
     output_md = 1
     output_gitbook = 0
     output_xmind = 0
@@ -565,6 +566,8 @@ def main():
     for k,v in opts:
         if k == "-f":
             js_file = v
+        if k == "-l":
+            link_path = v
         if k == "-h":
             usage()
             sys.exit()
