@@ -5,6 +5,12 @@ from xml.etree import ElementTree as ET
 class LibSVG(object):
     def __init__(self):
         self.cell = 20
+        self.bit_num = 32
+        self.bit_width = {
+                '32':20,
+                '8':40,
+                }
+
         pass
 
     def indent(self, elem, level=0):
@@ -25,7 +31,9 @@ class LibSVG(object):
             if level and (not elem.tail or not elem.tail.strip()):
                 elem.tail = i
 
-    def create_blank_form(self):
+    def create_blank_form(self, bit_num = 32):
+        self.bit_num = int(bit_num)
+        self.cell = int(self.bit_width[str(bit_num)])
         table = ET.Element('svg', attrib = {
             "baseProfile":"full",
             "width":"800",
@@ -50,12 +58,13 @@ class LibSVG(object):
             "stroke-width":"1",
             "transform":"translate(0,20.0)",
             })
-        ET.SubElement(line_group, 'line', attrib = {"x1":"0", "y1":"0", "x2":"640", "y2":"0"})
+        flen = str(self.bit_num * self.cell)
+        ET.SubElement(line_group, 'line', attrib = {"x1":"0", "y1":"0", "x2":flen, "y2":"0"})
         ET.SubElement(line_group, 'line', attrib = {"x1":"0", "y1":"0", "x2":"0", "y2":"40"})
-        ET.SubElement(line_group, 'line', attrib = {"x1":"0", "y1":"40", "x2":"640", "y2":"40"})
-        ET.SubElement(line_group, 'line', attrib = {"x1":"640", "y1":"0", "x2":"640", "y2":"40"})
-        for i in range(32):
-            x_p = str(i*20)
+        ET.SubElement(line_group, 'line', attrib = {"x1":"0", "y1":"40", "x2":flen, "y2":"40"})
+        ET.SubElement(line_group, 'line', attrib = {"x1":flen, "y1":"0", "x2":flen, "y2":"40"})
+        for i in range(self.bit_num):
+            x_p = str(i*self.cell)
             ET.SubElement(line_group, 'line', attrib = {"x1":x_p, "y1":"0", "x2":x_p, "y2":"5"})
             ET.SubElement(line_group, 'line', attrib = {"x1":x_p, "y1":"35", "x2":x_p, "y2":"40"})
 
@@ -74,12 +83,12 @@ class LibSVG(object):
             "stroke-width":"1",
             "transform":"translate(0,60.0)",
             })
-        ET.SubElement(ruler_group, 'line', attrib = {"x1":"0", "y1":"5", "x2":"640", "y2":"5"})
-        for i in range(9):
-            x_p = str(i*20*4)
+        ET.SubElement(ruler_group, 'line', attrib = {"x1":"0", "y1":"5", "x2":flen, "y2":"5"})
+        for i in range(int(self.bit_num /4) + 1):
+            x_p = str(i*self.cell*4)
             ET.SubElement(ruler_group, 'line', attrib = {"x1":x_p, "y1":"0", "x2":x_p, "y2":"10"})
             if i == 0:
-                x_p = str(10)
+                x_p = str(self.cell/2)
                 index_elem = ET.SubElement(ruler_group, 'text', attrib = {
                     "text-anchor":"middle",
                     "transform":"translate(0,17.0)",
@@ -88,9 +97,9 @@ class LibSVG(object):
                     "font-weight":"normal",
                     "x":x_p,
                     })
-                index_elem.text = str(31)
+                index_elem.text = str(self.bit_num - 1)
             else:
-                x_p = str(i*20*4 - 10)
+                x_p = str(i*self.cell*4 - int(self.cell/2))
                 index_elem = ET.SubElement(ruler_group, 'text', attrib = {
                     "text-anchor":"middle",
                     "transform":"translate(0,17.0)",
@@ -99,7 +108,7 @@ class LibSVG(object):
                     "font-weight":"normal",
                     "x":x_p,
                     })
-                index_elem.text = str(32-i*4)
+                index_elem.text = str(self.bit_num - i*4)
         return table
 
     def add_line(self, table, index_range):
@@ -107,7 +116,7 @@ class LibSVG(object):
         end = int(scope[0]) + 1
         start = int(scope[-1])
         for index in range(start, end):
-            re_index = 31 - index
+            re_index = self.bit_num - 1 - index
             if index == start:
                 self._add_long_string(table, re_index + 1)
             if index == end - 1:
@@ -128,7 +137,7 @@ class LibSVG(object):
         end = int(scope[0]) + 1
         start = int(scope[-1])
         middle = int((end + start)/2)
-        x_p = str(((31 - middle)*20 + 10)/1.414)
+        x_p = str(((self.bit_num - 1 - middle)*self.cell + (int(self.cell/2)))/1.414)
         value_elem = ET.SubElement(table[1][0], 'text', attrib = {
                 "font-family":"source code pro",
                 "font-size":"12",
@@ -143,8 +152,8 @@ class LibSVG(object):
             value_elem.text = "(" + name + ")"
 
     def _add_color(self, table, start, end):
-        x_p = str((31 - end + 1)*20)
-        width = str((end - start)*20)
+        x_p = str((self.bit_num - 1 - end + 1)*self.cell)
+        width = str((end - start)*self.cell)
         index_elem = ET.SubElement(table[1][2][2], 'rect', attrib = {
             "fill":"black",
             "fill-opacity":"0.1",
@@ -157,7 +166,7 @@ class LibSVG(object):
     def _add_value(self, table, start, end, value):
         if int(value, 16) == 0:
             for i in range(start, end):
-                x_p = str((31 - i)*20 - 10)
+                x_p = str((self.bit_num - 1 - i)*self.cell - 20 + int(self.cell/2))
                 index_elem = ET.SubElement(table[1][2][1], 'text', attrib = {
                     "font-family":"source code pro",
                     "font-size":"16",
@@ -168,7 +177,7 @@ class LibSVG(object):
         else:
             fill_list = list(bin(int(value, 16))[2:])
             for i in range(start, end):
-                x_p = str((31 - i)*20 - 10)
+                x_p = str((self.bit_num - 1 - i)*self.cell - 20 + int(self.cell/2))
                 index_elem = ET.SubElement(table[1][2][1], 'text', attrib = {
                     "font-family":"source code pro",
                     "font-size":"16",
@@ -182,7 +191,7 @@ class LibSVG(object):
 
     def _add_index(self, table, start, end):
         if end == start + 1:
-            x_p = str((31 - start)*20 - 10)
+            x_p = str((self.bit_num - 1 - start)*self.cell - 20 + int(self.cell/2))
             index_elem = ET.SubElement(table[1][2][0], 'text', attrib = {
                 "font-family":"source code pro",
                 "font-size":"12",
@@ -191,7 +200,7 @@ class LibSVG(object):
                 })
             index_elem.text = str(start)
         else:
-            start_p = str((31 - start)*20 - 10)
+            start_p = str((self.bit_num - 1 - start)*self.cell - 20 + int(self.cell/2))
             index_elem = ET.SubElement(table[1][2][0], 'text', attrib = {
                 "font-family":"source code pro",
                 "font-size":"12",
@@ -199,7 +208,7 @@ class LibSVG(object):
                 "x":start_p,
                 })
             index_elem.text = str(start)
-            end_p = str((31 - end)*20 + 10)
+            end_p = str((self.bit_num - 1 - end)*self.cell + self.cell + (int(self.cell/2) - 20))
             index_elem = ET.SubElement(table[1][2][0], 'text', attrib = {
                 "font-family":"source code pro",
                 "font-size":"12",
@@ -209,7 +218,7 @@ class LibSVG(object):
             index_elem.text = str(end - 1)
 
     def _add_long_string(self, table, index):
-        x_p = str(index * 20)
+        x_p = str(index * self.cell)
         ET.SubElement(table[1][1], 'line', attrib = {"x1":x_p, "y1":"0", "x2":x_p, "y2":"40"})
 
     def _add_short_string(self, table, index):
@@ -222,4 +231,12 @@ class LibSVG(object):
         return str(ET.tostring(table), 'utf-8') + "\n"
 
 if __name__ == "__main__":
-    pass
+    ls = LibSVG()
+    table = ls.create_blank_form(8)
+    ls.add_line(table, '[6:0]')
+    ls.indent(table)
+
+    svg_data = ls.svg_transform(table)
+    svg_name = 'demo.svg'
+    with open('demo.svg', 'w') as fd:
+        fd.write(svg_data)
