@@ -5,16 +5,15 @@ import os
 import re
 import sys
 from getopt import getopt
-try:
-    from JsonToMarkdown import preprocess
-    from JsonToMarkdown import libsvg
-    from JsonToMarkdown import libmd
-except ImportError:
-    import preprocess
-    import libsvg
-    import libmd
+BASE_DIR = os.path.dirname(os.path.abspath(__file__))
+sys.path.append(BASE_DIR)
+import preprocess
+import libsvg
+import libmd
+import cat as cat
+import json_to_obs as jo
 
-__version__ = 'v1.3.6'
+__version__ = 'v1.3.8'
 
 class TranslateJson(object):
     def __init__(self, js_file, link_path, dir_type, output_md, output_gitbook, output_xmind, \
@@ -45,7 +44,7 @@ class TranslateJson(object):
         self.all_reg_data = ''
         self.all_reg_tex_data = ''
         self.all_reg_list = []
-        self.reg_data = ''
+        self.reg_data = '# 寄存器详细说明\n\n'
         self.path_addr_dict = {}
         self.max_len = ''
         self.reg_rst = '寄存器详细说明\n==============\n\n.. toctree::\n'
@@ -461,7 +460,7 @@ class TranslateJson(object):
         #table_title = 'Register:' + name + ' ('  + addr + ')'
         reg_addr_msg = '地址偏移 : '  + addr
         reg_hex_reset = '默认值 : ' + hex_reset
-        register_data = "# " + name + "\n\n" + reg_addr_msg + '<br>' + \
+        register_data = "## " + name + "\n\n" + reg_addr_msg + '<br>' + \
                 reg_hex_reset + '\n' + register_data
         if self.output_md:
             os.system("mv " + svg_name + " " + self.markdownpath)
@@ -541,7 +540,7 @@ class TranslateJson(object):
 
     def get_gitlog(self):
         gitlog = ''
-        gitlog += '\n最近5次修改:\n\n'
+        gitlog += '# 最近修改:\n\n'
         gitlog += '|日期|作者|描述|commit_id|\n'
         gitlog += '|:---|:---|:---|:---|\n'
         json_dir = os.path.dirname(self.js_file)
@@ -549,15 +548,21 @@ class TranslateJson(object):
         cmd = 'git log --pretty=format:"| %ad | %cn | %s | %h |" --date=short'
         os.chdir(json_dir)
         fd = os.popen(cmd)
-        for i in range(5):
-            line = fd.readline()
-            gitlog += line
+        tmp = fd.readlines()
+        if len(tmp) >= 1:
+            for line in tmp:
+                gitlog += line
+        else:
+            gitlog += '|暂无|暂无|暂无|暂无|\n'
         os.chdir(now_dir)
+        with open(os.path.join(self.gitbookpath, 'gitlog.md'), 'w') as fc:
+            fc.write(gitlog)
         return gitlog
 
 
     def main(self):
         file_msg = os.path.basename(self.js_file).split(".json")[0]
+        self.file_msg = file_msg
         pp = preprocess.PreProcess()
         self.js_dict = pp.start(self.js_file)
         self.js_dpath = self.get_dpath(self.js_dict)
@@ -641,13 +646,13 @@ class TranslateJson(object):
                     except:
                         pass
                     with open(os.path.join(self.gitbookpath, 'all_register.md'), 'w') as fc:
-                        fc.write("## 寄存器列表\n\n" + self.all_reg_data + gitlog)
+                        fc.write("## 寄存器列表\n\n" + self.all_reg_data)
                     with open(os.path.join(self.gitbookpath, 'all_register_tex.md'), 'w') as fc:
-                        fc.write("## 寄存器列表\n\n" + self.all_reg_tex_data + gitlog)
+                        fc.write("## 寄存器列表\n\n" + self.all_reg_tex_data)
                     with open(os.path.join(self.gitbookpath, 'detail.md'), 'w') as fc:
                         fc.write(self.reg_data)
-                    with open(os.path.join(self.gitbookpath, 'detail.rst'), 'w') as fc:
-                        fc.write(self.reg_rst)
+                    #with open(os.path.join(self.gitbookpath, 'detail.rst'), 'w') as fc:
+                    #    fc.write(self.reg_rst)
                 self.check_file('README.md')
                 self.check_file('SUMMARY.md')
                 print("\n\tcreate " + self.gitbookpath +" success") 
@@ -733,5 +738,11 @@ def main():
             save_dir)
     tj.main()
 
+    tjo = jo.TranslateJson(js_file, link_path, dir_type, output_md, output_gitbook, \
+            output_xmind,save_dir)
+    tjo.main()
+    
+    cat.cat_md(link_path, tj.file_msg)
+
 if __name__ == "__main__":
     main()
