@@ -8,7 +8,7 @@ class PreProcess(object):
         pass
 
     def start(self, json_file):
-        with open(json_file, 'rb') as jf:
+        with open(json_file) as jf:
             js_dict = json.load(jf)
         return js_dict
 
